import { geoNaturalEarth1, geoPath, geoGraticule, geoMercator } from 'd3';

const projection = geoNaturalEarth1();
const path = geoPath(projection);
const graticule = geoGraticule();

export const Marks = ({
  mapData: { land, interiors },
  earthquakeData,
  sizeScale,
  sizeValue,
  colorScale,
  colorValue
}) => (
  <>
    <g className="marks">
      <path className="sphere" d={path({ type: 'Sphere' })} />
      <path className="graticules" d={path(graticule())} />
      {land.features.map(feature => (
        <path className="land" d={path(feature)} />
      ))}
      <path className="interiors" d={path(interiors)} />
      {earthquakeData.map((d, index) => {
        const [x, y] = projection([d.Longitude, d.Latitude]);
        const circle = <circle key={index} cx={x} cy={y} r={sizeScale(sizeValue(d))} fill={colorScale(colorValue(d))}></circle>;
        return circle;
      })}
    </g>
  </>
);
